#treatment_maps.py
import pandas as pd
import numpy as np
import seaborn as sns
import matplotlib.pyplot as plt
import geopandas as gpd 
from shapely.geometry import Point

hurricanes =['hermine','matthew','harvey', 'irma','florence','michael','dorian']
for h in hurricanes:
       df_list = []
       for file in glob.glob('geofiles/*_monthly_hermine_cf_geo.shp'):
           gdf = gpd.read_file(file)
           print (gdf.columns)
           gdf.drop('index_righ', axis=1, inplace=True)
           new_df = gdf[months].unstack().reset_index()
           new_df.drop('level_1', axis =1, inplace=True)
           new_df.rename({'level_0':'month', 0:'light'}, axis =1, inplace=True)
           new_df['geometry'] = np.tile(gdf.geometry, 12)
           new_df['county'] = np.tile(gdf.FIPS, 12)
           new_df['year'] = np.tile(gdf.year, 12)
           df_list.append(new_df)
       big_df = pd.concat(df_list)
       big_df.sort_values(by=['year'], inplace = True)
       #bound the lights between 0 and 50
       big_df = big_df[(big_df['light']>=0) & (big_df['light']<50)]
       big_df.reset_index(inplace = True)
       #chanage format of month & save
       month_dict = {month: index for index, month in enumerate(calendar.month_abbr) if month}
       big_df['month'] = big_df.month.apply(lambda x: month_dict[x])
       big_df['month'] = big_df['month'].astype(int)
       big_df['year'] = big_df['year'].astype(int)
       big_df['post'] = np.where(((big_df.year == 2016) & (big_df.month >= 9)) | (big_df.year > 2016), 1, 0)
       #read in fema data
       fema = pd.read_csv('fema_hermine.csv', sep=';').fillna(0)
       assistance = ['Individual Assistance','Public Assistance','PA-A','PA-B','PA-C','PA-D','PA-E','PA-F','PA-G','PA-H']
       ab_ass = ['PA-A', 'PA-B']
       fema['fema_tr'] = fema[assistance].sum(axis=1)
       fema['fema_pub_ab'] = fema[ab_ass].sum(axis=1)
       fema['fema_pub'] = fema['fema_tr'] - fema['Individual Assistance']
       fema['fema_treat'] = np.where(fema.fema_tr>0, 1, 0)
       fema['county'] = fema.FIPS
       fema.rename({'Individual Assistance':'fema_IA'}, axis =1, inplace=True)
       fema = fema[['county','fema_treat','fema_tr','fema_pub_ab', 'fema_pub', 'fema_IA']]
       fema.fillna(0, inplace=True)
       df1 = big_df.merge(fema, left_on= 'county', right_on = 'county')
       df1 = gpd.GeoDataFrame(df1, crs= {'init': 'epsg:4326'}, geometry= df1.geometry).to_crs(epsg=4326)
       counties = df1[['geometry','COUNTYFP']]
       fema_cs = df1[['geometry','fema_treat']]
       #plot
       fig, ax = plt.subplots()
       counties.plot(ax=ax, color = 'grey', label='Counties')
       fema_cs.plot(ax=ax, color = 'blue', label='FEMA')
       plt.legend(loc='best')
       plt.axis('off')
       plt.save(h+'treatment_counties.png')






